==> jc-1.4.0.tar.gz: java/awt/image/ShortLookupTable.h <==
// public class java.awt.image.ShortLookupTable

// class file dependencies
// @dep_class a552b3bb67ab409f java_awt_image_LookupTable
// @dep_class 299ed7384dc5269e java_awt_image_ShortLookupTable
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_awt_image_LookupTable

#include "java/awt/image/LookupTable.h"

#ifndef _JC_java_awt_image_ShortLookupTable_H_
#define _JC_java_awt_image_ShortLookupTable_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_awt_image_ShortLookupTable$sub_refs	_jc_java_awt_image_ShortLookupTable$sub_refs;
typedef struct _jc_java_awt_image_ShortLookupTable$sub_nonrefs	_jc_java_awt_image_ShortLookupTable$sub_nonrefs;
typedef struct _jc_java_awt_image_ShortLookupTable$refs	_jc_java_awt_image_ShortLookupTable$refs;
typedef struct _jc_java_awt_image_ShortLookupTable$nonrefs	_jc_java_awt_image_ShortLookupTable$nonrefs;
typedef struct _jc_java_awt_image_ShortLookupTable$object	_jc_java_awt_image_ShortLookupTable$object;

typedef const struct _jc_java_awt_image_ShortLookupTable$vmethods	_jc_java_awt_image_ShortLookupTable$vmethods;
typedef const struct _jc_java_awt_image_ShortLookupTable$vtable	_jc_java_awt_image_ShortLookupTable$vtable;
typedef const struct _jc_java_awt_image_ShortLookupTable$vtype	_jc_java_awt_image_ShortLookupTable$vtype;

// Constructors
extern void _jc_java_awt_image_ShortLookupTable$method$_init$2d913c082bac69b5(_jc_env *, struct _jc_java_awt_image_ShortLookupTable$object *, jint, struct _jc_short_array *);
extern void _jc_java_awt_image_ShortLookupTable$method$_init$d7f1282fff78ea24(_jc_env *, struct _jc_java_awt_image_ShortLookupTable$object *, jint, struct _jc_object_array *);

// Virtual methods
extern _jc_object_array *_jc_java_awt_image_ShortLookupTable$method$getTable$4391a5effadda1f0(_jc_env *, struct _jc_java_awt_image_ShortLookupTable$object *);
extern _jc_int_array *_jc_java_awt_image_ShortLookupTable$method$lookupPixel$0f1f0c9450fe78a3(_jc_env *, struct _jc_java_awt_image_ShortLookupTable$object *, struct _jc_int_array *, struct _jc_int_array *);
extern _jc_short_array *_jc_java_awt_image_ShortLookupTable$method$lookupPixel$b91ce8c739f6a905(_jc_env *, struct _jc_java_awt_image_ShortLookupTable$object *, struct _jc_short_array *, struct _jc_short_array *);

// Virtual method descriptors
extern _jc_method _jc_java_awt_image_ShortLookupTable$method_info$getTable$4391a5effadda1f0;
extern _jc_method _jc_java_awt_image_ShortLookupTable$method_info$lookupPixel$0f1f0c9450fe78a3;
extern _jc_method _jc_java_awt_image_ShortLookupTable$method_info$lookupPixel$b91ce8c739f6a905;

// Virtual methods structure
struct _jc_java_awt_image_ShortLookupTable$vmethods {
	_jc_object_array	*(*getTable$4391a5effadda1f0)(_jc_env *, struct _jc_java_awt_image_ShortLookupTable$object *);
	_jc_int_array	*(*lookupPixel$0f1f0c9450fe78a3)(_jc_env *, struct _jc_java_awt_image_ShortLookupTable$object *, struct _jc_int_array *, struct _jc_int_array *);
	_jc_short_array	*(*lookupPixel$b91ce8c739f6a905)(_jc_env *, struct _jc_java_awt_image_ShortLookupTable$object *, struct _jc_short_array *, struct _jc_short_array *);
};

// Vtable
struct _jc_java_awt_image_ShortLookupTable$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_image_LookupTable$vmethods	java_awt_image_LookupTable;
	_jc_java_awt_image_ShortLookupTable$vmethods	java_awt_image_ShortLookupTable;
};

// Vtype
struct _jc_java_awt_image_ShortLookupTable$vtype {
	_jc_type			type;
	_jc_java_awt_image_ShortLookupTable$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_image_ShortLookupTable$sub_refs {
	_jc_object_array	*data;
};

// Reference instance fields (object)
struct _jc_java_awt_image_ShortLookupTable$refs {
    _jc_java_awt_image_ShortLookupTable$sub_refs	java_awt_image_ShortLookupTable;
    _jc_java_awt_image_LookupTable$sub_refs	java_awt_image_LookupTable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_image_ShortLookupTable$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_image_ShortLookupTable$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_image_LookupTable$sub_nonrefs	java_awt_image_LookupTable;
    _jc_java_awt_image_ShortLookupTable$sub_nonrefs	java_awt_image_ShortLookupTable;
};

// Object instance structure
struct _jc_java_awt_image_ShortLookupTable$object {
	_jc_java_awt_image_ShortLookupTable$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_image_ShortLookupTable$vtype	*vtype;
	_jc_java_awt_image_ShortLookupTable$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_image_ShortLookupTable$vtype _jc_java_awt_image_ShortLookupTable$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_image_ShortLookupTable, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_image_ShortLookupTable$class_object;

#endif	/* _JC_java_awt_image_ShortLookupTable_H_ */

==> jc-1.4.6.tar.gz: java/awt/image/ShortLookupTable.h <==
// public class java.awt.image.ShortLookupTable

// class file dependencies
// @dep_class a552b3bb67ab409f java_awt_image_LookupTable
// @dep_class 299ed7384dc5269e java_awt_image_ShortLookupTable
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_awt_image_LookupTable

#include "java/awt/image/LookupTable.h"

#ifndef _JC_java_awt_image_ShortLookupTable_H_
#define _JC_java_awt_image_ShortLookupTable_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_awt_image_ShortLookupTable$sub_refs	_jc_java_awt_image_ShortLookupTable$sub_refs;
typedef struct _jc_java_awt_image_ShortLookupTable$sub_nonrefs	_jc_java_awt_image_ShortLookupTable$sub_nonrefs;
typedef struct _jc_java_awt_image_ShortLookupTable$refs	_jc_java_awt_image_ShortLookupTable$refs;
typedef struct _jc_java_awt_image_ShortLookupTable$nonrefs	_jc_java_awt_image_ShortLookupTable$nonrefs;
typedef struct _jc_java_awt_image_ShortLookupTable$object	_jc_java_awt_image_ShortLookupTable$object;

typedef const struct _jc_java_awt_image_ShortLookupTable$vmethods	_jc_java_awt_image_ShortLookupTable$vmethods;
typedef const struct _jc_java_awt_image_ShortLookupTable$vtable	_jc_java_awt_image_ShortLookupTable$vtable;
typedef const struct _jc_java_awt_image_ShortLookupTable$vtype	_jc_java_awt_image_ShortLookupTable$vtype;

// Constructors
extern void _jc_java_awt_image_ShortLookupTable$method$_init$2d913c082bac69b5(_jc_env *, struct _jc_java_awt_image_ShortLookupTable$object *, jint, struct _jc_short_array *) _JC_JCNI_ATTR;
extern void _jc_java_awt_image_ShortLookupTable$method$_init$d7f1282fff78ea24(_jc_env *, struct _jc_java_awt_image_ShortLookupTable$object *, jint, struct _jc_object_array *) _JC_JCNI_ATTR;

// Virtual methods
extern _jc_object_array *_jc_java_awt_image_ShortLookupTable$method$getTable$4391a5effadda1f0(_jc_env *, struct _jc_java_awt_image_ShortLookupTable$object *) _JC_JCNI_ATTR;
extern _jc_int_array *_jc_java_awt_image_ShortLookupTable$method$lookupPixel$0f1f0c9450fe78a3(_jc_env *, struct _jc_java_awt_image_ShortLookupTable$object *, struct _jc_int_array *, struct _jc_int_array *) _JC_JCNI_ATTR;
extern _jc_short_array *_jc_java_awt_image_ShortLookupTable$method$lookupPixel$b91ce8c739f6a905(_jc_env *, struct _jc_java_awt_image_ShortLookupTable$object *, struct _jc_short_array *, struct _jc_short_array *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_awt_image_ShortLookupTable$method_info$getTable$4391a5effadda1f0;
extern _jc_method _jc_java_awt_image_ShortLookupTable$method_info$lookupPixel$0f1f0c9450fe78a3;
extern _jc_method _jc_java_awt_image_ShortLookupTable$method_info$lookupPixel$b91ce8c739f6a905;

// Virtual methods structure
struct _jc_java_awt_image_ShortLookupTable$vmethods {
	_jc_object_array	*(*getTable$4391a5effadda1f0)(_jc_env *, struct _jc_java_awt_image_ShortLookupTable$object *) _JC_JCNI_ATTR;
	_jc_int_array	*(*lookupPixel$0f1f0c9450fe78a3)(_jc_env *, struct _jc_java_awt_image_ShortLookupTable$object *, struct _jc_int_array *, struct _jc_int_array *) _JC_JCNI_ATTR;
	_jc_short_array	*(*lookupPixel$b91ce8c739f6a905)(_jc_env *, struct _jc_java_awt_image_ShortLookupTable$object *, struct _jc_short_array *, struct _jc_short_array *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_awt_image_ShortLookupTable$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_image_LookupTable$vmethods	java_awt_image_LookupTable;
	_jc_java_awt_image_ShortLookupTable$vmethods	java_awt_image_ShortLookupTable;
};

// Vtype
struct _jc_java_awt_image_ShortLookupTable$vtype {
	_jc_type			type;
	_jc_java_awt_image_ShortLookupTable$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_image_ShortLookupTable$sub_refs {
	_jc_object_array	*data;
};

// Reference instance fields (object)
struct _jc_java_awt_image_ShortLookupTable$refs {
    _jc_java_awt_image_ShortLookupTable$sub_refs	java_awt_image_ShortLookupTable;
    _jc_java_awt_image_LookupTable$sub_refs	java_awt_image_LookupTable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_image_ShortLookupTable$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_image_ShortLookupTable$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_image_LookupTable$sub_nonrefs	java_awt_image_LookupTable;
    _jc_java_awt_image_ShortLookupTable$sub_nonrefs	java_awt_image_ShortLookupTable;
};

// Object instance structure
struct _jc_java_awt_image_ShortLookupTable$object {
	_jc_java_awt_image_ShortLookupTable$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_image_ShortLookupTable$vtype	*vtype;
	_jc_java_awt_image_ShortLookupTable$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_image_ShortLookupTable$vtype _jc_java_awt_image_ShortLookupTable$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_image_ShortLookupTable, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_image_ShortLookupTable$class_object;

#endif	/* _JC_java_awt_image_ShortLookupTable_H_ */
